@@ -89,13 +89,14 @@ struct impl {
 	unsigned int add_listener:1;
 	unsigned int have_format:1;
 	unsigned int started:1;
-	unsigned int warned:1;
 	unsigned int ready:1;
-	unsigned int driver:1;
 	unsigned int async:1;
 	unsigned int passthrough:1;
 	unsigned int follower_removing:1;
 	unsigned int in_recalc;
+
+	unsigned int warned:1;
+	unsigned int driver:1;
 };
 
 /** \endcond */
@@ -432,6 +433,9 @@ static int negotiate_buffers(struct impl *this)
 			SPA_PARAM_BUFFERS_align,   SPA_POD_OPT_Int(&align))) < 0)
 		return res;
 
+	if (this->async)
+		buffers = SPA_MAX(2u, buffers);
+
 	spa_log_debug(this->log, "%p: buffers:%d, blocks:%d, size:%d, stride:%d align:%d %d:%d",
 			this, buffers, blocks, size, stride, align, follower_alloc, conv_alloc);
 
@@ -923,15 +927,9 @@ static int impl_node_send_command(void *object, const struct spa_command *comman
 		this->warned = false;
 		break;
 	case SPA_NODE_COMMAND_Suspend:
-		this->started = false;
-		this->ready = false;
-		this->warned = false;
 		spa_log_debug(this->log, "%p: suspending", this);
 		break;
 	case SPA_NODE_COMMAND_Pause:
-		this->started = false;
-		this->ready = false;
-		this->warned = false;
 		spa_log_debug(this->log, "%p: pausing", this);
 		break;
 	case SPA_NODE_COMMAND_Flush:
@@ -968,9 +966,15 @@ static int impl_node_send_command(void *object, const struct spa_command *comman
 		break;
 	case SPA_NODE_COMMAND_Suspend:
 		configure_format(this, 0, NULL);
+		this->started = false;
+		this->warned = false;
+		this->ready = false;
 		spa_log_debug(this->log, "%p: suspended", this);
 		break;
 	case SPA_NODE_COMMAND_Pause:
+		this->started = false;
+		this->warned = false;
+		this->ready = false;
 		spa_log_debug(this->log, "%p: paused", this);
 		break;
 	case SPA_NODE_COMMAND_Flush:
@@ -1274,7 +1278,7 @@ static void follower_port_info(void *data,
 			}
 			if (idx == IDX_EnumFormat) {
 				spa_log_debug(this->log, "new formats");
-				configure_format(this, 0, NULL);
+				/* we will renegotiate when restarting */
 			}
 
 			this->params[idx].user++;
@@ -1568,7 +1572,7 @@ static int impl_node_process(void *object)
 	struct impl *this = object;
 	int status = 0, fstatus, retry = 8;
 
-	if (!this->started) {
+	if (!this->ready) {
 		if (!this->warned)
 			spa_log_warn(this->log, "%p: scheduling stopped node", this);
 		this->warned = true;
